All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH] net: plusb.c
@ 2010-09-12 15:27 Heiko Bauke
  0 siblings, 0 replies; only message in thread
From: Heiko Bauke @ 2010-09-12 15:27 UTC (permalink / raw)
  To: linux-kernel

[-- Attachment #1: Type: text/plain, Size: 402 bytes --]

Dear Kernel-Developers,

note that the plusb.c driver for Prolific PL-2301/2302 USB Host to Host
Link Driver may be used also for Prolific PL-2501 devices if a rather
trivial patch is applied to plusb.c.


	Regards,

	Heiko



-- 
--  Cluster Computing @ http://www.clustercomputing.de
-- Number Crunch Blog @ http://numbercrunch.de
--        Heiko Bauke @ http://www.mpi-hd.mpg.de/personalhomes/bauke

[-- Attachment #2: plusb.patch --]
[-- Type: text/x-patch, Size: 1531 bytes --]

diff -urN linux_orig/drivers/net/usb/plusb.c linux_new/drivers/net/usb/plusb.c
--- linux_orig/drivers/net/usb/plusb.c	2010-09-12 17:07:08.377086065 +0200
+++ linux_new/drivers/net/usb/plusb.c	2010-09-12 17:10:06.088880446 +0200
@@ -1,5 +1,5 @@
 /*
  * PL-2301/2302 USB host-to-host link cables
  * Copyright (C) 2000-2005 by David Brownell
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,7 @@
 
 
 /*
- * Prolific PL-2301/PL-2302 driver ... http://www.prolifictech.com
+ * Prolific PL-2301/2302/2501 driver ... http://www.prolifictech.com
  *
  * The protocol and handshaking used here should be bug-compatible
  * with the Linux 2.2 "plusb" driver, by Deti Fliegl.
@@ -95,7 +95,7 @@
 }
 
 static const struct driver_info	prolific_info = {
-	.description =	"Prolific PL-2301/PL-2302",
+	.description =	"Prolific PL-2301/2302/2501",
 	.flags =	FLAG_NO_SETINT,
 		/* some PL-2302 versions seem to fail usb_set_interface() */
 	.reset =	pl_reset,
@@ -117,6 +117,9 @@
 }, {
 	USB_DEVICE(0x067b, 0x0001),	// PL-2302
 	.driver_info =	(unsigned long) &prolific_info,
+}, {
+	USB_DEVICE(0x067b, 0x2501),	// PL-2501
+	.driver_info =	(unsigned long) &prolific_info,
 },
 
 	{ },		// END
@@ -145,5 +148,5 @@
 module_exit(plusb_exit);
 
 MODULE_AUTHOR("David Brownell");
-MODULE_DESCRIPTION("Prolific PL-2301/2302 USB Host to Host Link Driver");
+MODULE_DESCRIPTION("Prolific PL-2301/2302/2501 USB Host to Host Link Driver");
 MODULE_LICENSE("GPL");

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2010-09-12 15:40 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -1,5 +1,5 @@
 /*
- * PL-2301/2302 USB host-to-host link cables
+ * PL-2301/2302/2501 USB host-to-host link cables
  * Copyright (C) 2000-2005 by David Brownell
  *
2010-09-12 15:27 [PATCH] net: plusb.c Heiko Bauke

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.